##  Connecting to the MCP Server
To learn how to connect to the MCP server from your AI client, visit [Connecting to the MCP Server](https://help.sap.com/docs/leanix/ea/connecting-to-mcp-server?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to connect to the MCP server and view example client configurations.").
